==> tucnak1_1.32.orig.tar.gz: tucnak1-1.32.orig/src/setup.h <==

/*
   This file is stolen from links
*/   

#define VERSION_STRING          VERSION

#define DEBUG
#define LEAK_DEBUG
#define LEAK_DEBUG_LIST

/*#define MAX_REDIRECTS           10*/

#define MAX_HISTORY_ITEMS       256
#define MENU_HOTKEY_SPACE       2

#define COL(x)              ((x)*0x100)

#define COLOR_MENU          COL(070)
#define COLOR_MENU_FRAME        COL(070)
#define COLOR_MENU_SELECTED     COL(007)
#define COLOR_MENU_HOTKEY       COL(007)

#define COLOR_MAINMENU          COL(070)
#define COLOR_MAINMENU_SELECTED     COL(007)
#define COLOR_MAINMENU_HOTKEY       COL(070)

#define COLOR_DIALOG            COL(070)
#define COLOR_DIALOG_FRAME      COL(070)
#define COLOR_DIALOG_TITLE      COL(007)
#define COLOR_DIALOG_TEXT       COL(070)
#define COLOR_DIALOG_CHECKBOX       COL(070)
#define COLOR_DIALOG_CHECKBOX_TEXT  COL(070)
#define COLOR_DIALOG_BUTTON     COL(070)
#define COLOR_DIALOG_BUTTON_SELECTED    COL(0107)
#define COLOR_DIALOG_FIELD      COL(007)
#define COLOR_DIALOG_FIELD_TEXT     COL(007)

#define SCROLL_ITEMS            2

#define DIALOG_LEFT_BORDER      3
#define DIALOG_TOP_BORDER       1
#define DIALOG_LEFT_INNER_BORDER    2
#define DIALOG_TOP_INNER_BORDER     0
#define DIALOG_FRAME            2

#define DIALOG_LB   (DIALOG_LEFT_BORDER + DIALOG_LEFT_INNER_BORDER + 1)
#define DIALOG_TB   (DIALOG_TOP_BORDER + DIALOG_TOP_INNER_BORDER + 1)

#define COL_BG   COL(0x07)
#define COL_NORM COL(0x07)
#define COL_INV  COL(0x38)

#define ESC_TIMEOUT         200


#define RESOURCE_INFO_REFRESH       300


#define NET_PORT 55555
#define MAX_INTERFACES 16
/* msec */
#define UDP_ANNOUNCE 10000
#define CONNECTION_TIMEOUT 30000
#define SEND_ACK_TIMEOUT 10000
#define ACK_TIMEOUT 20000
#define REMOVE_TIMEOUT 10000
#define DELAY_AFTER_REPLICATION 1000

/* sec */
#define NET_GLOBAL_EXPIRE 60
#define NET_MAX_SKEW_POS 120
#define NET_MAX_SKEW_NEG 60

/*
TIPS: (all in seconds)

REMOVE_TIMEOUT < NET_GLOBAL_EXPIRE*1000
UDP_ANNOUNCE * 3 < NET_GLOBAL_EXPIRE*1000
skew=60
NET_MAX_SKEW_NEG=skew
NET_MAX_SKEW_POS=NET_GLOBAL_EXPIRE+skew   
*/   

/*#define SUSPCHAR "?"*/

#define IL_HIST_LEN 20


/* cwdb */

/* length of call, other characters are ignored*/
/*#define MAX_QS_LEN 10 */

/* A-Z, 0-9, '/' */
/*#define MAX_QS_ITEMS (26+10+1)*/

/* maximal count of matches */
/*#define MAX_CW_MATCHES 15
#define MAX_OBAND_MATCHES 15
#define MAX_BAND_MATCHES 15*/

#define MAX_CQ 6

==> tucnak2_2.11.orig.tar.gz: tucnak2-2.11.orig/src/setup.h <==
/*
    Tucnak - VHF contest log
    Copyright (C) 2002-2006  Ladislav Vaiz <ok1zia@nagano.cz>
    and authors of web browser Links 0.96

    This program is free software; you can redistribute it and/or                                                        
    modify it under the terms of the GNU General Public License                                                          
    version 2 as published by the Free Software Foundation.

*/


#define VERSION_STRING          VERSION

#define DEBUG
/*#define LEAK_DEBUG
#define LEAK_DEBUG_LIST*/

/*#define MAX_REDIRECTS           10*/

#define MAX_HISTORY_ITEMS       256
#define MENU_HOTKEY_SPACE       2

#define COL(x)              ((x)*0x100)

#define COLOR_MENU1          COL(070)
#define COLOR_MENU_FRAME        COL(070)
#define COLOR_MENU_SELECTED     COL(007)
#define COLOR_MENU_HOTKEY       COL(007)

#define COLOR_MAINMENU          COL(070)
#define COLOR_MAINMENU_SELECTED     COL(007)
#define COLOR_MAINMENU_HOTKEY       COL(070)

#define COLOR_DIALOG            COL(070)
#define COLOR_DIALOG_FRAME      COL(070)
#define COLOR_DIALOG_TITLE      COL(007)
#define COLOR_DIALOG_TEXT       COL(070)
#define COLOR_DIALOG_CHECKBOX       COL(070)
#define COLOR_DIALOG_CHECKBOX_TEXT  COL(070)
#define COLOR_DIALOG_BUTTON     COL(070)
#define COLOR_DIALOG_BUTTON_SELECTED    COL(0107)
#define COLOR_DIALOG_FIELD      COL(007)
#define COLOR_DIALOG_FIELD_TEXT     COL(007)

#define SCROLL_ITEMS            2

#define DIALOG_LEFT_BORDER      3
#define DIALOG_TOP_BORDER       1
#define DIALOG_LEFT_INNER_BORDER    2
#define DIALOG_TOP_INNER_BORDER     0
#define DIALOG_FRAME            2

#define DIALOG_LB   (DIALOG_LEFT_BORDER + DIALOG_LEFT_INNER_BORDER + 1)
#define DIALOG_TB   (DIALOG_TOP_BORDER + DIALOG_TOP_INNER_BORDER + 1)

#define COL_BG         COL(0x07)
#define COL_NORM       COL(0x07)
#define COL_INV        COL(0x38)
#define COL_YELLOW     COL(0x43) 
#define COL_DARKYELLOW COL(0x03) 
#define COL_RED        COL(0x41) 

#define ESC_TIMEOUT         200


#define RESOURCE_INFO_REFRESH       300


#define NET_PORT 55555
#define MAX_INTERFACES 16
/* msec */
#define UDP_ANNOUNCE 10000
#define CONNECTION_TIMEOUT 30000
#define SEND_ACK_TIMEOUT 10000
#define ACK_TIMEOUT 20000
#define REMOVE_TIMEOUT 10000
#define DELAY_AFTER_REPLICATION 1000

/* sec */
#define NET_GLOBAL_EXPIRE 60
#define NET_MAX_SKEW_POS 120
#define NET_MAX_SKEW_NEG 60

/*
TIPS: (all in seconds)

REMOVE_TIMEOUT < NET_GLOBAL_EXPIRE*1000
UDP_ANNOUNCE * 3 < NET_GLOBAL_EXPIRE*1000
skew=60
NET_MAX_SKEW_NEG=skew
NET_MAX_SKEW_POS=NET_GLOBAL_EXPIRE+skew   
*/   

/*#define SUSPCHAR "?"*/

#define IL_HIST_LEN 20


/* cwdb */

/* length of call, other characters are ignored*/
/*#define MAX_QS_LEN 10 */

/* A-Z, 0-9, '/' */
/*#define MAX_QS_ITEMS (26+10+1)*/

/* maximal count of matches */
/*#define MAX_CW_MATCHES 15
#define MAX_OBAND_MATCHES 15
#define MAX_BAND_MATCHES 15*/

#define MAX_CQ 6
